@@ -916,6 +916,10 @@ var gApplicationsPane = {
       self._rebuildVisibleTypes();
       self._sortVisibleTypes();
       self._rebuildView();
+
+      // Notify observers that the UI is now ready
+      Cc["@mozilla.org/observer-service;1"].getService(Ci.nsIObserverService).
+      notifyObservers(window, "app-handler-pane-loaded", null);
     }
     setTimeout(_delayedPaneLoad, 0, this);
   },
@@ -1286,7 +1290,7 @@ var gApplicationsPane = {
 //          just don't know how to do that via script...
 // XXXmano TBD: can probably add this to nsIShellService
    aExecutable.leafName != "firefox-bin";
-//@line 1363 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 1367 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
   },
 
   /**
@@ -1407,7 +1411,7 @@ var gApplicationsPane = {
     }
 
     // Create a menu item for selecting a local application.
-//@line 1490 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 1494 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
     {
       let menuItem = document.createElement("menuitem");
       menuItem.setAttribute("oncommand", "gApplicationsPane.chooseApp(event)");
@@ -1649,7 +1653,7 @@ var gApplicationsPane = {
 
     var handlerApp;
 
-//@line 1761 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 1765 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
     var fp = Cc["@mozilla.org/filepicker;1"].createInstance(Ci.nsIFilePicker);
     var winTitle = this._prefsBundle.getString("fpTitleChooseApp");
     fp.init(window, winTitle, Ci.nsIFilePicker.modeOpen);
@@ -1668,7 +1672,7 @@ var gApplicationsPane = {
       let handlerInfo = this._handledTypes[this._list.selectedItem.type];
       handlerInfo.addPossibleApplicationHandler(handlerApp);
     }
-//@line 1780 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 1784 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
 
     // Rebuild the actions menu whether the user picked an app or canceled.
     // If they picked an app, we want to add the app to the menu and select it.
